flexdds

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 14, 2023 License: MIT Imports: 4 Imported by: 0

README

Wieserlabs FlexDDS

The present repository contains a command-line interface (CLI) to the network interface of the Wieserlabs FlexDDS-NG.

Usage

You can download the compiled binaries for your platform from the GitHub release tab.

Convert

The flexdds-convert tool supports you in the conversion of the output frequency and the amplitude scale to the register values, e.g.,

./flexdds-convert freq-out 10e6
# Output: 0x28f5c29

./flexdds-convert log-ampl-scale 0.0
# Output: 0x4000

./flexdds-convert lin-ampl-scale 0.0
# Output: 0x0
Control

The flexdds-control tool allows you to configure a slot of the FlexDDS, e.g., to singletone output:

./flexdds-control \
    --host=10.163.100.7 \
    --slot=2 \
    --channel=0 \
    --system-clock=1e9 \
    singletone \
        --log-amplitude=0.0 \
        --frequency=60e6

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client is a telnet client to the Client controller.

func Open

func Open(c Config) (*Client, error)

Open returns a new Client client for a controller with addr and DDS slot.

func (*Client) Close

func (c *Client) Close() error

Close closes the telnet connection.

func (*Client) Singletone

func (c *Client) Singletone(ch uint8, ampl, freq float64) error

Singletone configures channel to output a single frequency with relative amplitude.

type Config

type Config struct {
	Host     string
	Slot     uint16
	SysClock float64
}

Directories

Path Synopsis
cmd
control command
convert command

Jump to